/*
 * Copyright © 2017 eSignLive by Vasco.
 * Proprietary and confidential.
 * Unauthorized copying of this file, via any medium is strictly prohibited
 *
 */

package com.esignlive.app;

import android.app.Application;
import android.net.Uri;

import com.esignlive.sdk.AuthenticationListener;
import com.esignlive.sdk.ESignLive;
import com.esignlive.sdk.ESignLiveContextProvider;
import com.esignlive.sdk.TemplateDownloadListener;
import com.esignlive.sdk.TemplateListListener;
import com.esignlive.sdk.TransactionListListener;
import com.esignlive.sdk.datamodel.User;
import com.esignlive.sdk.datamodel.manage.Role;
import com.esignlive.sdk.datamodel.manage.Template;
import com.esignlive.sdk.datamodel.manage.Transaction;
import com.esignlive.sdk.preparation.Approval;
import com.esignlive.sdk.preparation.CreateTransactionViewModel;
import com.esignlive.sdk.preparation.FormField;
import com.esignlive.sdk.preparation.Signature;
import com.esignlive.sdk.utility.Error;

import java.util.ArrayList;

/**
 * Created by qsuleiman on 2017-08-17.
 */

public class Recipes implements ESignLiveContextProvider {

    public void setup(){

        ESignLive.setContextProvider(this);
        ESignLive.getInstance().setServerAddress("https://sandbox.esignlive.com");
        ESignLive.getInstance().setRootActivityProvider(null); //Should be the activity, the ESL SDK is called on top

        ESignLive.getInstance().setSyncOnWifiOnly(true);
        ESignLive.getInstance().setAutoSync(false);
    }

    public void login(AuthenticationListener authenticationListener){
        ESignLive.getInstance().login("email", "password", authenticationListener);
    }

    public void getTransactionList(final TransactionListListener transactionListListener){
        this.login(new AuthenticationListener() {
            @Override
            public void loginSucceeded(User user, boolean isOnlineLogin) {
                ESignLive.getInstance().getTransactionList(Transaction.TransactionFilter.REQUIRES_YOUR_SIGNATURE, 0, 10, transactionListListener);
            }

            @Override
            public void loginFailed(Error error) {

            }
        });
    }

    public void startTransaction(){
        this.getTransactionList(new TransactionListListener() {
            @Override
            public void downloadTransactionListSucceeded(Transaction.TransactionFilter type, int startIndex, ArrayList<Transaction> transactions, int transactionsCount) {
                Transaction transaction =  transactions.get(0);
                ESignLive.getInstance().startTransactionWithId(transaction.getId(),true);
            }

            @Override
            public void downloadTransactionListFailed(Error error) {

            }
        });
    }

    public void createTransactionWithCode(){

        Transaction transaction = CreateTransactionViewModel.createTransaction("My Transaction");
        try {
            CreateTransactionViewModel.setInPersonSigning(transaction.getId(),true);
            Role role = CreateTransactionViewModel.addRole(transaction.getId(),"John","Snow","johnsnow@winterfell.com","Wolfs","King in the north");

            Approval approval = CreateTransactionViewModel.addApproval(role.getId());
            FormField formField = new Signature();
            approval.addField(formField);

            java.util.List<Approval> approvals = new ArrayList();
            approvals.add(approval);


            Uri docPath = null;//provide the path to document
            CreateTransactionViewModel.addDocument(transaction.getId(), docPath, "Declaration of legitimacy", "John is no longer a snow", null,approvals,new CreateTransactionViewModel.AddDocumentListener() {
                @Override
                public void documentAddSuccessful(String transactionId, String documentId) {
                    CreateTransactionViewModel.sendTransaction(transactionId);
                    ESignLive.getInstance().startTransactionWithId(transactionId,true);
                }

                @Override
                public void documentAddFailed(String transactionId, String documentId, Error error) {

                }
            });



        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    public void createTransactionWithUserInterface(){
        this.login(new AuthenticationListener() {
            @Override
            public void loginSucceeded(User user, boolean isOnlineLogin) {
                ESignLive.getInstance().createNewTransactionUsingSdkUserInterface();
            }

            @Override
            public void loginFailed(Error error) {

            }
        });

    }

    public void getTemplateList(final TemplateListListener templateListListener){
        this.login(new AuthenticationListener() {
            @Override
            public void loginSucceeded(User user, boolean isOnlineLogin) {
                ESignLive.getInstance().getTemplateList(Template.TemplateFilter.ALL_TEMPLATES, 0, 10,templateListListener);
            }

            @Override
            public void loginFailed(Error error) {

            }
        });
    }

    public void createTransactionWithTemplates(){
         this.getTemplateList(new TemplateListListener() {
             @Override
             public void downloadingTemplateListSucceeded(Template.TemplateFilter type, int startIndex, ArrayList<Template> templates, int templatesCount) {
                 Template template = templates.get(0);
                 CreateTransactionViewModel.createTransactionFromTemplate("My Transaction",template.getId(), null);
             }

             @Override
             public void downloadingTemplateListFailed(Error error) {

             }
         });
    }

    public void downloadTemplateForOfflineUse(){
        this.getTemplateList(new TemplateListListener() {
            @Override
            public void downloadingTemplateListSucceeded(Template.TemplateFilter type, int startIndex, ArrayList<Template> templates, int templatesCount) {
                Template template = templates.get(0);
                ESignLive.getInstance().downloadTemplateWithId(template.getId(), new TemplateDownloadListener() {
                    @Override
                    public void downloadTemplateSucceeded(Template template) {
                        //You can even create from here
                    }

                    @Override
                    public void downloadTemplateFailed(String templateId, Error error) {

                    }
                });
            }

            @Override
            public void downloadingTemplateListFailed(Error error) {

            }
        });
    }

    @Override
    public Application getApplicationContext() {
        return null;
    }
}
