package com.esignlive.app;

import android.support.annotation.Nullable;

import com.esignlive.sdk.backend.datastore.ObjectPersistentManager;
import com.esignlive.sdk.backend.datastore.system.Account;

import java.io.Serializable;

/**
 * Created by eSignLive on 16-06-16.
 */
public class UserData implements Serializable {

    // Constants
    public static String USER_DATA_KEY = "com.esl.app.userData";

    // Properties
    private String email;
    private String password;
    private String firstName;
    private String lastName;
    private boolean isLoggedIn;
    @Nullable private Account account;

    private boolean isEmailEncrypted, isPasswordEncrypted;

    // Constructor
    public UserData() {
        this.email    = "";
        this.password = "";
        this.isLoggedIn = false;
    }

    // Getters
    public String getEmail() {
        try {
            if (this.isEmailEncrypted == true) {
                return this.email;
            } else {
                return this.email;
            }
        } catch (Exception ignored) {
            return this.email;
        }
    }
    public String getPassword() {
        try {
            if (this.isPasswordEncrypted == true) {
                return this.password;
            } else {
                return password;
            }
        } catch (Exception ignored) {
            return password;
        }
    }
    public boolean isLoggedIn() {
        return isLoggedIn;
    }
    public String getFirstName() {
        return firstName;
    }
    public String getLastName() {
        return lastName;
    }
    public String getFullName() {
        String result = "";
        if (this.firstName != null && !this.firstName.isEmpty()) {
            result += this.firstName;
        }
        if (this.lastName != null && !this.lastName.isEmpty()) {
            result += " " + this.lastName;
        }
        return result;
    }
    @Nullable public Account getAccount() {
        return account;
    }

    // Setters
    public void setEmail(String email) {
        this.email = email;
    }
    public void setPassword(String password) {
        this.password = password;
    }
    public void setLoggedIn(boolean loggedIn) {
        isLoggedIn = loggedIn;
    }
    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }
    public void setLastName(String lastName) {
        this.lastName = lastName;
    }
    public void setAccount(@Nullable Account account) {
        this.account = account;
    }

    // Methods
    public static void storeLoggedInUserDetails(String email, String password) {
        UserData userData = new UserData();
        userData.setEmail(email);
        userData.setPassword(password);
        userData.setLoggedIn(true);
        ObjectPersistentManager.storeObject(userData,USER_DATA_KEY);
    }
    public static void storeLoggedInUserDetails(String firstName, String lastName, String email, String password, Account account, boolean isLoggedIn) {
        UserData userData = lastLoggedInUserData();
        if (userData == null) {
            userData = new UserData();
        }
        userData.setFirstName(firstName);
        userData.setLastName(lastName);
        userData.setEmail(email);
        userData.setPassword(password);
        userData.setLoggedIn(isLoggedIn);
        userData.setAccount(account);
        ObjectPersistentManager.storeObject(userData,USER_DATA_KEY);
    }
    public static UserData lastLoggedInUserData(){
        return (UserData)ObjectPersistentManager.getObject(USER_DATA_KEY);
    }
    public static boolean isUserLoggedIn() {
        UserData userData = lastLoggedInUserData();
        if (userData != null) {
            return userData.isLoggedIn();
        }
        return false;
    }
    public static void setUserNotLoggedIn(){
        UserData userData = lastLoggedInUserData();
        if (userData != null){
            userData.setLoggedIn(false);
        }
        ObjectPersistentManager.storeObject(userData,USER_DATA_KEY);
    }
    public static void setUserLoggedIn(@Nullable String email) {
        UserData userData = lastLoggedInUserData();
        if (userData == null) {
            userData = new UserData();
        }
        if (email != null) {
            userData.setEmail(email);
        }
        userData.setLoggedIn(true);
        ObjectPersistentManager.storeObject(userData,USER_DATA_KEY);
    }

}
